P4 to Git Change 2037147 by kjayapra@1_HIPWS_LNX1_PAL on 2019/11/26 16:58:07
SWDEV-144570 - Adding hipMemcpyWithStream API
Affected files ...
... //depot/stg/opencl/drivers/opencl/api/hip/hip_hcc.def.in#36 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_hcc.map.in#34 edit
... //depot/stg/opencl/drivers/opencl/api/hip/hip_memory.cpp#87 edit
[ROCm/clr commit: d2570e2254]
Este commit está contenido en:
@@ -81,6 +81,7 @@ hipMallocArray
|
||||
hipMemAllocPitch
|
||||
hipMallocPitch
|
||||
hipMemcpy
|
||||
hipMemcpyWithStream
|
||||
hipMemcpyParam2D
|
||||
hipMemcpy2D
|
||||
hipMemcpy2DAsync
|
||||
|
||||
@@ -82,6 +82,7 @@ global:
|
||||
hipMallocPitch;
|
||||
hipMemAllocPitch;
|
||||
hipMemcpy;
|
||||
hipMemcpyWithStream;
|
||||
hipMemcpyParam2D;
|
||||
hipMemcpy2D;
|
||||
hipMemcpy2DAsync;
|
||||
|
||||
@@ -233,6 +233,15 @@ hipError_t hipMemcpy(void* dst, const void* src, size_t sizeBytes, hipMemcpyKind
|
||||
HIP_RETURN(ihipMemcpy(dst, src, sizeBytes, kind, *queue));
|
||||
}
|
||||
|
||||
hipError_t hipMemcpyWithStream(void* dst, const void* src, size_t sizeBytes,
|
||||
hipMemcpyKind kind, hipStream_t stream) {
|
||||
HIP_INIT_API(hipMemcpyWithStream, dst, src, sizeBytes, kind, stream);
|
||||
|
||||
amd::HostQueue* queue = hip::getQueue(stream);
|
||||
|
||||
HIP_RETURN(ihipMemcpy(dst, src, sizeBytes, kind, *queue, true));
|
||||
}
|
||||
|
||||
hipError_t hipMemPtrGetInfo(void *ptr, size_t *size) {
|
||||
HIP_INIT_API(hipMemPtrGetInfo, ptr, size);
|
||||
|
||||
|
||||
Referencia en una nueva incidencia
Block a user